( cd usr/bin ; rm -rf amstex )
( cd usr/bin ; ln -sf virtex amstex )
( cd usr/lib/texmf/ini ; rm -rf amstex.fmt )
( cd usr/lib/texmf/ini ; ln -sf /cdrom/live/usr/lib/texmf/ini/amstex.fmt amstex.fmt )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf READ.ME )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/READ.ME READ.ME )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf amsguide.tex )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/amsguide.tex amsguide.tex )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf amsppt.doc )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/amsppt.doc amsppt.doc )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf amstex.bug )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/amstex.bug amstex.bug )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf amstinst.tex )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/amstinst.tex amstinst.tex )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf joyerr.tex )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/joyerr.tex joyerr.tex )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf userdoc.cyr )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/userdoc.cyr userdoc.cyr )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf userdoc.def )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/userdoc.def userdoc.def )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf userdoc.fnt )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/userdoc.fnt userdoc.fnt )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf userdoc.ins )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/userdoc.ins userdoc.ins )
( cd usr/lib/texmf/tex/amstex/doc ; rm -rf userdoc.tex )
( cd usr/lib/texmf/tex/amstex/doc ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/doc/userdoc.tex userdoc.tex )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amsfonts.lst )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amsfonts.lst amsfonts.lst )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amsppt.sty )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amsppt.sty amsppt.sty )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amsppt1.tex )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amsppt1.tex amsppt1.tex )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amssym.def )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amssym.def amssym.def )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amssym.tex )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amssym.tex amssym.tex )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amstex.ini )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amstex.ini amstex.ini )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf amstex.tex )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/amstex.tex amstex.tex )
( cd usr/lib/texmf/tex/amstex/macros ; rm -rf cyracc.def )
( cd usr/lib/texmf/tex/amstex/macros ; ln -sf /cdrom/live/usr/lib/texmf/tex/amstex/macros/cyracc.def cyracc.def )
( cd usr/man/preformat/cat1 ; rm -rf amstex.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/amstex.1.gz amstex.1.gz )
( cd usr/man/preformat/cat1 ; rm -rf lamstex.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf /cdrom/live/usr/man/preformat/cat1/lamstex.1.gz lamstex.1.gz )
